import numpy as np
import pytest
import kdtree
from sklearn.neighbors import KDTree


@pytest.mark.parametrize("n", [10, 100, 1000, 10000])
@pytest.mark.parametrize("d", [10, 100])
@pytest.mark.parametrize("leaf_size", [256, 1024])
def test_creation_deletion(n, d, leaf_size):
    np.random.seed(1)
    X = np.random.rand(n, d)

    tree = kdtree.KDTree(X, leaf_size=256)
    del tree

@pytest.mark.skip(reason="The query is being refactored.")
@pytest.mark.parametrize("n", [10, 100, 1000, 10000])
@pytest.mark.parametrize("d", [10, 100])
@pytest.mark.parametrize("k", [1, 2, 5, 10])
@pytest.mark.parametrize("leaf_size", [256, 1024])
def test_against_sklearn(n, d, k, leaf_size):
    np.random.seed(1)
    X = np.random.rand(n, d)
    query_points = np.random.rand(n, d)

    tree = kdtree.KDTree(X, leaf_size=256)
    skl_tree = KDTree(X, leaf_size=256)

    closests = np.zeros((n, k), dtype=np.int32)
    tree.query(query_points, closests)
    skl_closests = skl_tree.query(query_points, k=k, return_distance=False).astype(np.int32)
    np.testing.assert_equal(closests, skl_closests)
